@@ -142,8 +142,8 @@ MessageQueueJob *MessageQueuer::createQueueJob()
     job->addressAttribute().setBcc(mBccEdit->text().isEmpty()
                                    ? QStringList() : mBccEdit->text().split(QLatin1Char(',')));
 
-    connect(job, SIGNAL(result(KJob*)),
-            SLOT(jobResult(KJob*)));
+    connect(job, &MessageQueueJob::result,
+            this, &MessageQueuer::jobResult);
     connect(job, SIGNAL(percent(KJob*,ulong)),
             SLOT(jobPercent(KJob*,ulong)));
     connect(job, SIGNAL(infoMessage(KJob*,QString,QString)),
